# coding: utf-8

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from amgix_client.models.custom_document_vector import CustomDocumentVector
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class Document(BaseModel):
    """
    Document model representing the structure of documents in the system.  This model is used for document ingestion, retrieval, and search results. Content is excluded from database storage for performance and cost reasons.
    """ # noqa: E501
    id: Annotated[str, Field(strict=True, max_length=100)] = Field(description="Unique identifier for the document (max 100 characters)")
    timestamp: datetime = Field(description="UTC timestamp when the document was created/updated")
    tags: Optional[Annotated[List[StrictStr], Field(max_length=50)]] = Field(default=None, description="List of document tags (max 50 items; each max 100 characters; cannot contain pipe characters)")
    name: Optional[Annotated[str, Field(strict=True, max_length=1500)]] = Field(default=None, description="Document name (max 1500 characters)")
    description: Optional[Annotated[str, Field(strict=True, max_length=3000)]] = Field(default=None, description="Brief description of the document (max 3000 characters)")
    content: Optional[Annotated[str, Field(strict=True, max_length=1000000)]] = Field(default=None, description="Main content of the document (max 1000000 characters)")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Dictionary of metadata key-value pairs. Values can be simple types (string, int, float, bool) or MetaValue objects (required for datetime)")
    custom_vectors: Optional[List[CustomDocumentVector]] = Field(default=None, description="Pre-generated custom vectors for this document (optional)")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "timestamp", "tags", "name", "description", "content", "metadata", "custom_vectors"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Document from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in custom_vectors (list)
        _items = []
        if self.custom_vectors:
            for _item_custom_vectors in self.custom_vectors:
                if _item_custom_vectors:
                    _items.append(_item_custom_vectors.to_dict())
            _dict['custom_vectors'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Document from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "timestamp": obj.get("timestamp"),
            "tags": obj.get("tags"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "content": obj.get("content"),
            "metadata": obj.get("metadata"),
            "custom_vectors": [CustomDocumentVector.from_dict(_item) for _item in obj["custom_vectors"]] if obj.get("custom_vectors") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


