# coding: utf-8

# flake8: noqa
"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from amgix_client.models.bulk_upload_request import BulkUploadRequest
from amgix_client.models.collection_config import CollectionConfig
from amgix_client.models.collection_exists_response import CollectionExistsResponse
from amgix_client.models.custom_document_vector import CustomDocumentVector
from amgix_client.models.custom_vector import CustomVector
from amgix_client.models.document import Document
from amgix_client.models.document_status import DocumentStatus
from amgix_client.models.document_status_response import DocumentStatusResponse
from amgix_client.models.http_validation_error import HTTPValidationError
from amgix_client.models.metadata_filter import MetadataFilter
from amgix_client.models.metadata_index import MetadataIndex
from amgix_client.models.ok_response import OkResponse
from amgix_client.models.queue_info import QueueInfo
from amgix_client.models.ready_response import ReadyResponse
from amgix_client.models.search_query import SearchQuery
from amgix_client.models.search_result import SearchResult
from amgix_client.models.validation_error import ValidationError
from amgix_client.models.validation_error_loc_item import ValidationErrorLocItem
from amgix_client.models.vector import Vector
from amgix_client.models.vector_config import VectorConfig
from amgix_client.models.vector_score import VectorScore
from amgix_client.models.vector_search_weight import VectorSearchWeight
from amgix_client.models.version_response import VersionResponse

