# coding: utf-8

# flake8: noqa

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.0"

# Define package exports
__all__ = [
    "AmgixApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BulkUploadRequest",
    "CollectionConfig",
    "CollectionExistsResponse",
    "CustomDocumentVector",
    "CustomVector",
    "Document",
    "DocumentStatus",
    "DocumentStatusResponse",
    "HTTPValidationError",
    "MetadataFilter",
    "MetadataIndex",
    "OkResponse",
    "QueueInfo",
    "ReadyResponse",
    "SearchQuery",
    "SearchResult",
    "ValidationError",
    "ValidationErrorLocItem",
    "Vector",
    "VectorConfig",
    "VectorScore",
    "VectorSearchWeight",
    "VersionResponse",
]

# import apis into sdk package
from amgix_client.api.amgix_api import AmgixApi as AmgixApi

# import ApiClient
from amgix_client.api_response import ApiResponse as ApiResponse
from amgix_client.api_client import ApiClient as ApiClient
from amgix_client.configuration import Configuration as Configuration
from amgix_client.exceptions import OpenApiException as OpenApiException
from amgix_client.exceptions import ApiTypeError as ApiTypeError
from amgix_client.exceptions import ApiValueError as ApiValueError
from amgix_client.exceptions import ApiKeyError as ApiKeyError
from amgix_client.exceptions import ApiAttributeError as ApiAttributeError
from amgix_client.exceptions import ApiException as ApiException

# import models into sdk package
from amgix_client.models.bulk_upload_request import BulkUploadRequest as BulkUploadRequest
from amgix_client.models.collection_config import CollectionConfig as CollectionConfig
from amgix_client.models.collection_exists_response import CollectionExistsResponse as CollectionExistsResponse
from amgix_client.models.custom_document_vector import CustomDocumentVector as CustomDocumentVector
from amgix_client.models.custom_vector import CustomVector as CustomVector
from amgix_client.models.document import Document as Document
from amgix_client.models.document_status import DocumentStatus as DocumentStatus
from amgix_client.models.document_status_response import DocumentStatusResponse as DocumentStatusResponse
from amgix_client.models.http_validation_error import HTTPValidationError as HTTPValidationError
from amgix_client.models.metadata_filter import MetadataFilter as MetadataFilter
from amgix_client.models.metadata_index import MetadataIndex as MetadataIndex
from amgix_client.models.ok_response import OkResponse as OkResponse
from amgix_client.models.queue_info import QueueInfo as QueueInfo
from amgix_client.models.ready_response import ReadyResponse as ReadyResponse
from amgix_client.models.search_query import SearchQuery as SearchQuery
from amgix_client.models.search_result import SearchResult as SearchResult
from amgix_client.models.validation_error import ValidationError as ValidationError
from amgix_client.models.validation_error_loc_item import ValidationErrorLocItem as ValidationErrorLocItem
from amgix_client.models.vector import Vector as Vector
from amgix_client.models.vector_config import VectorConfig as VectorConfig
from amgix_client.models.vector_score import VectorScore as VectorScore
from amgix_client.models.vector_search_weight import VectorSearchWeight as VectorSearchWeight
from amgix_client.models.version_response import VersionResponse as VersionResponse

