# coding: utf-8

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class MetadataFilter(BaseModel):
    """
    Recursive metadata filter structure (modeled on Qdrant filter with and/or/not).
    """ # noqa: E501
    var_and: Optional[List[MetadataFilter]] = Field(default=None, description="All conditions in this list must match (AND)", alias="and")
    var_or: Optional[List[MetadataFilter]] = Field(default=None, description="Any condition in this list must match (OR)", alias="or")
    var_not: Optional[MetadataFilter] = Field(default=None, description="This condition must NOT match (NOT)", alias="not")
    key: Optional[StrictStr] = Field(default=None, description="Metadata field key (for field condition)")
    op: Optional[StrictStr] = Field(default=None, description="Comparison operator")
    value: Optional[Any] = None
    __properties: ClassVar[List[str]] = ["and", "or", "not", "key", "op", "value"]

    @field_validator('op')
    def op_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['eq', 'lt', 'gt', 'lte', 'gte']):
            raise ValueError("must be one of enum values ('eq', 'lt', 'gt', 'lte', 'gte')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetadataFilter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in var_and (list)
        _items = []
        if self.var_and:
            for _item_var_and in self.var_and:
                if _item_var_and:
                    _items.append(_item_var_and.to_dict())
            _dict['and'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_or (list)
        _items = []
        if self.var_or:
            for _item_var_or in self.var_or:
                if _item_var_or:
                    _items.append(_item_var_or.to_dict())
            _dict['or'] = _items
        # override the default output from pydantic by calling `to_dict()` of var_not
        if self.var_not:
            _dict['not'] = self.var_not.to_dict()
        # set to None if value (nullable) is None
        # and model_fields_set contains the field
        if self.value is None and "value" in self.model_fields_set:
            _dict['value'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetadataFilter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "and": [MetadataFilter.from_dict(_item) for _item in obj["and"]] if obj.get("and") is not None else None,
            "or": [MetadataFilter.from_dict(_item) for _item in obj["or"]] if obj.get("or") is not None else None,
            "not": MetadataFilter.from_dict(obj["not"]) if obj.get("not") is not None else None,
            "key": obj.get("key"),
            "op": obj.get("op"),
            "value": obj.get("value")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
MetadataFilter.model_rebuild(raise_errors=False)

