# coding: utf-8

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class DocumentStatus(BaseModel):
    """
    Individual status entry for a document.
    """ # noqa: E501
    status: StrictStr = Field(description="Status of the document (queued, requeued, indexed, failed)")
    info: Optional[StrictStr] = Field(default=None, description="Status information")
    timestamp: datetime = Field(description="When this status occurred")
    queue_id: Optional[StrictStr] = Field(default=None, description="Queue entry ID (only for queue-related statuses)")
    try_count: Optional[StrictInt] = Field(default=None, description="Number of processing attempts (only for failed statuses)")
    __properties: ClassVar[List[str]] = ["status", "info", "timestamp", "queue_id", "try_count"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['queued', 'requeued', 'indexed', 'failed']):
            raise ValueError("must be one of enum values ('queued', 'requeued', 'indexed', 'failed')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DocumentStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DocumentStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "status": obj.get("status"),
            "info": obj.get("info"),
            "timestamp": obj.get("timestamp"),
            "queue_id": obj.get("queue_id"),
            "try_count": obj.get("try_count")
        })
        return _obj


